@@ -19,6 +19,6 @@
 
 LIBDIR = r'/clangarm64/lib'
 DATADIR = r'/clangarm64/share'
-BUILDDIR = r'C:/M/B/src/build-CLANGARM64'
-SRCDIR = r'C:/M/B/src/gst-devtools-1.26.1'
+BUILDDIR = r'C:/W/B/src/build-CLANGARM64'
+SRCDIR = r'C:/W/B/src/gst-devtools-1.26.2'
 GST_VALIDATE_TESTSUITE_VERSION = '1.26'
